.emacs .hll { background-color: #ffffcc }
.emacs .c { color: #008800; font-style: italic } /* Comment */
.emacs .err { border: 1px solid #FF0000 } /* Error */
.emacs .k { color: #AA22FF; font-weight: bold } /* Keyword */
.emacs .o { color: #666666 } /* Operator */
.emacs .ch { color: #008800; font-style: italic } /* Comment.Hashbang */
.emacs .cm { color: #008800; font-style: italic } /* Comment.Multiline */
.emacs .cp { color: #008800 } /* Comment.Preproc */
.emacs .cpf { color: #008800; font-style: italic } /* Comment.PreprocFile */
.emacs .c1 { color: #008800; font-style: italic } /* Comment.Single */
.emacs .cs { color: #008800; font-weight: bold } /* Comment.Special */
.emacs .gd { color: #A00000 } /* Generic.Deleted */
.emacs .ge { font-style: italic } /* Generic.Emph */
.emacs .gr { color: #FF0000 } /* Generic.Error */
.emacs .gh { color: #000080; font-weight: bold } /* Generic.Heading */
.emacs .gi { color: #00A000 } /* Generic.Inserted */
.emacs .go { color: #888888 } /* Generic.Output */
.emacs .gp { color: #000080; font-weight: bold } /* Generic.Prompt */
.emacs .gs { font-weight: bold } /* Generic.Strong */
.emacs .gu { color: #800080; font-weight: bold } /* Generic.Subheading */
.emacs .gt { color: #0044DD } /* Generic.Traceback */
.emacs .kc { color: #AA22FF; font-weight: bold } /* Keyword.Constant */
.emacs .kd { color: #AA22FF; font-weight: bold } /* Keyword.Declaration */
.emacs .kn { color: #AA22FF; font-weight: bold } /* Keyword.Namespace */
.emacs .kp { color: #AA22FF } /* Keyword.Pseudo */
.emacs .kr { color: #AA22FF; font-weight: bold } /* Keyword.Reserved */
.emacs .kt { color: #00BB00; font-weight: bold } /* Keyword.Type */
.emacs .m { color: #666666 } /* Literal.Number */
.emacs .s { color: #BB4444 } /* Literal.String */
.emacs .na { color: #BB4444 } /* Name.Attribute */
.emacs .nb { color: #AA22FF } /* Name.Builtin */
.emacs .nc { color: #0000FF } /* Name.Class */
.emacs .no { color: #880000 } /* Name.Constant */
.emacs .nd { color: #AA22FF } /* Name.Decorator */
.emacs .ni { color: #999999; font-weight: bold } /* Name.Entity */
.emacs .ne { color: #D2413A; font-weight: bold } /* Name.Exception */
.emacs .nf { color: #00A000 } /* Name.Function */
.emacs .nl { color: #A0A000 } /* Name.Label */
.emacs .nn { color: #0000FF; font-weight: bold } /* Name.Namespace */
.emacs .nt { color: #008000; font-weight: bold } /* Name.Tag */
.emacs .nv { color: #B8860B } /* Name.Variable */
.emacs .ow { color: #AA22FF; font-weight: bold } /* Operator.Word */
.emacs .w { color: #bbbbbb } /* Text.Whitespace */
.emacs .mb { color: #666666 } /* Literal.Number.Bin */
.emacs .mf { color: #666666 } /* Literal.Number.Float */
.emacs .mh { color: #666666 } /* Literal.Number.Hex */
.emacs .mi { color: #666666 } /* Literal.Number.Integer */
.emacs .mo { color: #666666 } /* Literal.Number.Oct */
.emacs .sa { color: #BB4444 } /* Literal.String.Affix */
.emacs .sb { color: #BB4444 } /* Literal.String.Backtick */
.emacs .sc { color: #BB4444 } /* Literal.String.Char */
.emacs .dl { color: #BB4444 } /* Literal.String.Delimiter */
.emacs .sd { color: #BB4444; font-style: italic } /* Literal.String.Doc */
.emacs .s2 { color: #BB4444 } /* Literal.String.Double */
.emacs .se { color: #BB6622; font-weight: bold } /* Literal.String.Escape */
.emacs .sh { color: #BB4444 } /* Literal.String.Heredoc */
.emacs .si { color: #BB6688; font-weight: bold } /* Literal.String.Interpol */
.emacs .sx { color: #008000 } /* Literal.String.Other */
.emacs .sr { color: #BB6688 } /* Literal.String.Regex */
.emacs .s1 { color: #BB4444 } /* Literal.String.Single */
.emacs .ss { color: #B8860B } /* Literal.String.Symbol */
.emacs .bp { color: #AA22FF } /* Name.Builtin.Pseudo */
.emacs .fm { color: #00A000 } /* Name.Function.Magic */
.emacs .vc { color: #B8860B } /* Name.Variable.Class */
.emacs .vg { color: #B8860B } /* Name.Variable.Global */
.emacs .vi { color: #B8860B } /* Name.Variable.Instance */
.emacs .vm { color: #B8860B } /* Name.Variable.Magic */
.emacs .il { color: #666666 } /* Literal.Number.Integer.Long */
