/* styling for all html tags */
body{
    background: #f5f6f7;
    color: grey;
    border-color: grey;
    overflow: hidden;
    padding: 0px;
    height: 100%;
}
pre{
    overflow: visible !important;
}
td{
    vertical-align: top;
}


/* styling for generic classes */
.flip180{
    -webkit-transform: rotate(180deg);
    -moz-transform: rotate(180deg);
    -o-transform: rotate(180deg);
    -ms-transform: rotate(180deg);
    transform: rotate(180deg);
}
.inline{
    display: inline;
}
.bold{
    font-weight: bold;
}
.pre{
    white-space: pre;
}
.stderr{
    color: #ff3434;
}
.monospace{
    font-family: Menlo,Monaco,Consolas,"Courier New",monospace;
}
.memadr, .memadr_react{  /* todo - migrate everything to react, then rename memadr_react to memadr  */
    color: #489ce4;
    text-decoration: none;
}
.lighttext{
    color: #4a4a4a;
}
.glyphicon{
    /* glyphicons are too bold, make them lighter*/
        color: #848484;
}
.visibility_toggler{
    cursor: pointer;
}
.placeholder{
    color: #ccc;
    font-style: italic;
}
.flex{
    display: flex;
}
.flexrow{
    display: flex;
    flex-direction: row;
}
.flexcol{
    display: flex;
    flex-direction: column;
}
/* components get their own titlebars */
.titlebar{
    width: 100%;
    color: black;
    background-color: #ddf1ff;
    border-color: #c3c3c3;
    border-width: 1px;
    border-style: solid;
}
.pointer{
    cursor: pointer;
}
.collapser:hover .rowresizer{
  cursor: row-resize;
  height: 10px;
  width: 100%;
  background-color: white;
  background-repeat: no-repeat;
  background-position: 50%;
  background-image: url('/static/vendor/images/splitjs/grips/horizontal.png');
}
.collapser .rowresizer{
  height: 10px;
  width: 100%;
  background-color: white;
}
.sent_command{
    color: #00d8ff;
}
.sent_command:hover, .autocmplt:hover{
    /* lighten background */
    background-color:rgba(255,255,255,0.1)
}
.disabled {
        background-color: lightgrey;
        opacity: 0.6;
        pointer-events: none;
}
.margin_sm{
    margin: 2px;
}
.no_padding{
    padding: 2px !important;
}
.highlight{
    background: rgba(255, 255, 0, 0.5) !important;
}
div.breakpoint{
    border: solid;
    cursor: pointer;
    /* need top and bottom border so when hovering and showing border on row, there is no "jumping" */
    border-width: 0px;
    border-top-width: 1px;
    border-right-width: 1px;
    border-bottom-width: 1px;
    border-color: #f5f5f5; /* make border color the same as the background color */
}
.breakpoint td{
    padding-top: 1px !important;
    padding-bottom: 1px !important;
}
.breakpoint:hover{
    background-color: #f5f5f5;
}
.breakpoint_trashcan, .right_help_icon_show_on_hover{
    margin-right: 5px;
    display: none !important;
}
div.breakpoint:hover div.breakpoint_trashcan,
.varLI:hover .right_help_icon_show_on_hover{
    display: inline !important;
}
.line_num{
    width: 50px;
    border-width: 0px;
    border-top-width: 1px;
    border-top-color: transparent;
    border-right-width: 1px;
    border-bottom-width: 0px;
    border-style: solid;
    border-right-color: #c7c7c7;
    padding-left: 10px;
    padding-right: 10px;
    font-size: 0.9em;
    color: #ababab;
    cursor: pointer;
}
/* the line number has its style changed if it has a breakpoint */
.line_num.breakpoint, .line_num.disabled_breakpoint{
    color: black;
}
.line_num.breakpoint{
    background: #33cdff !important;
    border-style: solid;
    /*border-top-width: 1px;*/
    border-right-width: 0px;
    /*border-bottom-width: 1px;*/
    border-left-width: 0px;
    border-color: transparent;
}
.line_num.disabled_breakpoint{
    background: #ffd6d7 !important;
}
td.assembly{
    padding-bottom: 0px;
    padding-top: 0px;
    white-space: nowrap;
}
/* instruction content */
.instrContent{
    min-width: 250px;
    display:inline-block;
}
#code_table{
    font-family: monospace;
    border-collapse: separate;
    font-size: 0.9em;
}
.srccode td{
    padding-left: 3px;
    padding-bottom: 0px;
    padding-top: 0px;
    border-style: solid;
    border-top-width: 1px;
    border-right-width: 1px;
    border-bottom-width: 1px;
    border-left-width: 0px;
    border-color: transparent;
}
td.line_num{
    border-style: solid;
    border-right-width: 1px;
    border-top-width: 0px;
    border-bottom-width: 0px;
    border-left-width: 0px;
    border-right-color: #d4d4d4;
    border-top-color: transparent;
    border-bottom-color: transparent;
}
/* wsp == whitespace. Needed to preserve leading whitespace.
    this span wraps syntax-highlighted source code */
.wsp{
    white-space: pre;
}

.current_assembly_command{
    font-weight: bold;
}
.padding_left{
    padding-left: 5px;
}
.loc{
    height: 18px
}
.paused_on_line {
    border-width: 0px;
}
.dropdown-btn {
        vertical-align: top;
        height: 30px;
        border-top-left-radius: 0;
        border-bottom-left-radius: 0;
}
#memory table{
    font-family: monospace;
}
.memory_char:empty{
    content: ?;
}

/* specific styling for ids or components */
#always_on_top{
    position: fixed;
    top: 0;
    margin-top: 0;
    width: 100%;
    border-bottom: black;
    border-style: solid;
    border-width: 0px;
    z-index: 1000;
    background: #f1f1f1;
}
#console_container{
    height: 100%;
    position: relative;
}
#console{
    background-color: #292929;
    color: #d6d6d6 !important;
    font-family: Menlo,Monaco,Consolas,"Courier New",monospace !important;
    width: 100%;
    overflow: auto;
    font-size: 0.9em;
    border-bottom: 0;
    border-bottom-left-radius: 0;
    border-bottom-right-radius: 0;
    position: absolute;
    left: 0;
    top: 0;
    bottom: 30px;
}
#filesystem ul,
#filesystem li
{
  listStyleType: none;
  padding: 0;
}
#gdb_command_input, #gdb_command_input .gdb_command_input{
    height: 30px;
    border-width: 0;
    background-color: #3c3c3c !important;
    color: #f9f9f9 !important;
    font-family: Menlo,Monaco,Consolas,"Courier New",monospace !important;
}
#gdb_command_input{
    width: 100%;
    height: 30px;
    position: absolute;
    bottom: 0px;
    left: 0px;
}
#gdb_command_input tr td:nth-child(1) {
    width: 30px;
    vertical-align: middle;
}
#gdb_command_input tr td:nth-child(2) {
    width: 100%;
}
#gdb_command_input tr td:nth-child(3) {
    width: 15px;
    vertical-align: middle;
    padding-right: 10px;
}
#gdb_command_input .gdb_command_input:focus{
    outline-color: none;
    box-shadow: none;
}
.fullscreen_modal{
    padding: 10px;
    width: 100%;
    height: 100%;
    position: fixed;
    left: 0;
    top: 0;
    z-index: 120;
    background: rgba(0,0,0, 0.8);
    overflow: auto;
}
.blur{
    filter: blur(3px);
}
#gdb_settings_modal{
    width: 800px;
    padding: 40px;
    z-index: 120;
    background: white;
    max-height: 85%;
    overflow: auto;
    margin-left: auto;
    margin-right: auto;
}
.modal_content{
    padding: 20px;
    margin-top: 10px;
    margin-left: auto;
    margin-right: auto;
    background: white;
    margin: auto;
    border: 1px solid #888;
    border-radius: 4px;
    width: 500px;
    box-shadow: 0 5px 15px rgba(0,0,0,.5);
}

#hovervar{
    background: white;
    width: 350px;
    height: 200px;
    position: absolute;
    top: 0;
    left: 0;
    visibility: none;
    overflow: auto;
    padding: 10px;
    border: solid 1px #989898;
    border-radius: 4px;
    /* http://www.cssmatic.com/box-shadow */
    -webkit-box-shadow: 9px 10px 31px 0px rgba(0,0,0,0.75);
    -moz-box-shadow: 9px 10px 31px 0px rgba(0,0,0,0.75);
    box-shadow: 9px 10px 31px 0px rgba(0,0,0,0.75);
}

.otpt{ /* output (shortened to keep dom as small as possible */
    min-height: 1em;
    margin: 2px;
    white-space: pre;
}
.gdbguiConsoleOutput{
    color: orange;
    min-height: 1em;
    margin: 2px;
    white-space: pre;
}
#gdb_mi_output{
    font-family: Menlo,Monaco,Consolas,"Courier New",monospace;
    overflow: auto;
    font-size: 0.9em;
    height: 300px;
    width: 100%;
}

/* styling for "Expressions" component */
#expressions li, #locals li, #hovervar li{
    list-style: none;
}
#expressions, #locals, #hovervar{
    white-space: nowrap;
    font-family: monospace;
    font-size: 0.9em;
    overflow: auto;
    margin: 0;
    padding: 0;
}

.varLI .btn-radix{
    display: none!important;
}
.varLI:hover .btn-radix{
    display: inline !important;
}

ul.varUL{
        padding-left: 0;
        padding-top: 0;
        border: 0;
        margin: 0;
}
/* Show type of variable in lighter text */
.var_type{
    color: #a0a0a0;
    margin-left: 5px;
    font-style: italic;
}
.plot{
    width: 300px;
    height: 200px;
    display: visible;
}
#plot_coordinate_tooltip{
    position: fixed;
    display: none;
    border: 1px solid #828282;
    padding: 2px;
    background-color: #f5f5f5;
}
#threads ul{
    list-style: none;
    padding: 0;
}
#memory table{
    font-size: 0.9em;
}

/* Make refresh icon spin - http://www.bootply.com/128062*/
.glyphicon-refresh-animate {
        -animation: spin .7s infinite linear;
        -webkit-animation: webkit-spin .7s infinite linear;
}

@-webkit-keyframes webkit-spin {
        from { -webkit-transform: rotate(0deg);}
        to { -webkit-transform: rotate(360deg);}
}

@keyframes spin {
        from { transform: scale(1) rotate(0deg);}
        to { transform: scale(1) rotate(360deg);}
}
