/* splitjs is so unopinionated, it doesn't work without specific css classes (float: left) when splitting into two side-by-side
 panes ("horizonal" */
/* splitjs classes for splitting the body of the webpage (https://github.com/nathancahill/Split.js) */
html, body, .splitjs_container {  /* for splitjs, it's important that html also has these properties, not just body */
height: 100%;
padding: 0;
margin: 0;
background-color: #333;
box-sizing: border-box;
overflow: hidden;
}

.split {
-webkit-box-sizing: border-box;
   -moz-box-sizing: border-box;
        box-sizing: border-box;

overflow-y: hidden;
overflow-x: hidden;
}

.content {
border: 0px solid #C0C0C0;
box-shadow: inset 0 1px 2px #e4e4e4;
background-color: #fff;
overflow: auto;
float: left;
height: 100%;
width: 100%;
}

.gutter{
    background: lightgrey;
}
.gutter.gutter-horizontal {
cursor: col-resize;
}

.gutter.gutter-vertical {
cursor: row-resize;
}

.split.split-horizontal, .gutter.gutter-horizontal {
height: 100%;
float: left;
}
