<!DOCTYPE html>
<html>
  <head>
    <title>gdbgui - gdb in a browser</title>
    <base target="_blank">
    <link href="static/vendor/css/bootstrap.min.css" rel="stylesheet">
    <link href="static/vendor/css/animate.css" rel="stylesheet">
    <link rel="shortcut icon" href="{{ url_for('static', filename='favicon.ico') }}">
    <script type="text/javascript" src="static/vendor/js/jquery.min.js"></script>
  </head>
  <style>
    body{
        background-color: white;
    }
    hr{
        width: 90%;
    }
    .square {
        height: 200px;
        width: 200px;
        display: inline-block;
        margin: 10px;
        transition: background-color .4s;
        font-size: 1.1em;
        padding: 20px;
        border-style: solid;
        border-color: #ccc;
        border-width: 1px;
        background-color: white;
        vertical-align: top;
        border-radius: 10px;
    }
    .square:hover {
        background-color: #dff7ff;
    }
    a:hover{
        text-decoration: none;
    }
    ul{
        list-style-type: none;
        padding-left: 2px;
    }
  </style>
  <body style="position: fixed; width: 100%; height: 100%;">
    <div class="container-fluid">
      <p></p>
      {% if debug == true %}
        <h3>gdbgui not shutting down because debug is true</h3>
      {% else %}
        <h3>gdbgui has been shut down</h3>
        <script>
          (function(){
              $.ajax({
                  beforeSend: function(xhr) {
                    xhr.setRequestHeader("x-csrftoken", {{ csrf_token | tojson }} );
                  },
                  url: "/_shutdown",
                  cache: false,
                  method: 'POST',
                  success: null,
                  error: null,
              })
          })()
        </script>
      {% endif %}
    </div>
  </body>
</html>
