/* gdbgui-specific stuff*/
.monokai {
    background-color: #333;
    color: grey;
}

/* when hovering, set background color of entire row */
.monokai .paused_on_line {
    background-color: #444;
}

.monokai .assembly { color: #d8d8d8; }

/* show a flash of color */
.monokai .flash {
    -webkit-animation-name: flash-animation-monokai;
    -webkit-animation-duration: 3.0s;

    animation-name: flash-animation-monokai;
    animation-duration: 3.0s;
}

@-webkit-keyframes flash-animation-monokai {
    from { background: white; }
    from { background: #444; }
    to   { background: default; }
}

@keyframes flash-animation-monokai {
    from { background: white; }
    from { background: #444; }
    to   { background: default; }
}


/* generated by pygments */
.monokai .hll { background-color: #49483e }
.monokai .c { color: #75715e } /* Comment */
.monokai .err { color: #960050; background-color: #1e0010 } /* Error */
.monokai .k { color: #66d9ef } /* Keyword */
.monokai .l { color: #ae81ff } /* Literal */
.monokai .n { color: #f8f8f2 } /* Name */
.monokai .o { color: #f92672 } /* Operator */
.monokai .p { color: #f8f8f2 } /* Punctuation */
.monokai .ch { color: #75715e } /* Comment.Hashbang */
.monokai .cm { color: #75715e } /* Comment.Multiline */
/*.monokai .cp { color: #75715e } /* Comment.Preproc  THIS IS PROVIDED BY PYGMENTS BUT LOOKS WRONG*/
.monokai .cp { color: #e8636f } /* Comment.Preproc UPDATED FOR GDBGUI HERE (pink, not grey) */

/*.monokai .cpf { color: #75715e } /* Comment.PreprocFile THIS IS PROVIDED BY PYGMENTS BUT LOOKS WRONG */
.monokai .cpf { color: #fbff00 } /* Comment.PreprocFile UPDATED FOR GDBGUI HERE (yellow, not grey) */

.monokai .c1 { color: #75715e } /* Comment.Single */
.monokai .cs { color: #75715e } /* Comment.Special */
.monokai .gd { color: #f92672 } /* Generic.Deleted */
.monokai .ge { font-style: italic } /* Generic.Emph */
.monokai .gi { color: #a6e22e } /* Generic.Inserted */
.monokai .gs { font-weight: bold } /* Generic.Strong */
.monokai .gu { color: #75715e } /* Generic.Subheading */
.monokai .kc { color: #66d9ef } /* Keyword.Constant */
.monokai .kd { color: #66d9ef } /* Keyword.Declaration */
.monokai .kn { color: #f92672 } /* Keyword.Namespace */
.monokai .kp { color: #66d9ef } /* Keyword.Pseudo */
.monokai .kr { color: #66d9ef } /* Keyword.Reserved */
.monokai .kt { color: #66d9ef } /* Keyword.Type */
.monokai .ld { color: #e6db74 } /* Literal.Date */
.monokai .m { color: #ae81ff } /* Literal.Number */
.monokai .s { color: #e6db74 } /* Literal.String */
.monokai .na { color: #a6e22e } /* Name.Attribute */
.monokai .nb { color: #f8f8f2 } /* Name.Builtin */
.monokai .nc { color: #a6e22e } /* Name.Class */
.monokai .no { color: #66d9ef } /* Name.Constant */
.monokai .nd { color: #a6e22e } /* Name.Decorator */
.monokai .ni { color: #f8f8f2 } /* Name.Entity */
.monokai .ne { color: #a6e22e } /* Name.Exception */
.monokai .nf { color: #a6e22e } /* Name.Function */
.monokai .nl { color: #f8f8f2 } /* Name.Label */
.monokai .nn { color: #f8f8f2 } /* Name.Namespace */
.monokai .nx { color: #a6e22e } /* Name.Other */
.monokai .py { color: #f8f8f2 } /* Name.Property */
.monokai .nt { color: #f92672 } /* Name.Tag */
.monokai .nv { color: #f8f8f2 } /* Name.Variable */
.monokai .ow { color: #f92672 } /* Operator.Word */
.monokai .w { color: #f8f8f2 } /* Text.Whitespace */
.monokai .mb { color: #ae81ff } /* Literal.Number.Bin */
.monokai .mf { color: #ae81ff } /* Literal.Number.Float */
.monokai .mh { color: #ae81ff } /* Literal.Number.Hex */
.monokai .mi { color: #ae81ff } /* Literal.Number.Integer */
.monokai .mo { color: #ae81ff } /* Literal.Number.Oct */
.monokai .sa { color: #e6db74 } /* Literal.String.Affix */
.monokai .sb { color: #e6db74 } /* Literal.String.Backtick */
.monokai .sc { color: #e6db74 } /* Literal.String.Char */
.monokai .dl { color: #e6db74 } /* Literal.String.Delimiter */
.monokai .sd { color: #e6db74 } /* Literal.String.Doc */
.monokai .s2 { color: #e6db74 } /* Literal.String.Double */
.monokai .se { color: #ae81ff } /* Literal.String.Escape */
.monokai .sh { color: #e6db74 } /* Literal.String.Heredoc */
.monokai .si { color: #e6db74 } /* Literal.String.Interpol */
.monokai .sx { color: #e6db74 } /* Literal.String.Other */
.monokai .sr { color: #e6db74 } /* Literal.String.Regex */
.monokai .s1 { color: #e6db74 } /* Literal.String.Single */
.monokai .ss { color: #e6db74 } /* Literal.String.Symbol */
.monokai .bp { color: #f8f8f2 } /* Name.Builtin.Pseudo */
.monokai .fm { color: #a6e22e } /* Name.Function.Magic */
.monokai .vc { color: #f8f8f2 } /* Name.Variable.Class */
.monokai .vg { color: #f8f8f2 } /* Name.Variable.Global */
.monokai .vi { color: #f8f8f2 } /* Name.Variable.Instance */
.monokai .vm { color: #f8f8f2 } /* Name.Variable.Magic */
.monokai .il { color: #ae81ff } /* Literal.Number.Integer.Long */
