/* gdbgui-specific stuff */
.light {
    background-color: white;
    color: black;
}

/* when hovering, set background color of entire row */
.light .paused_on_line {
    background-color: #bbefff;
}

.light .assembly { color: black; }

/* show a flash of color */
.light .flash {
    -webkit-animation-name: flash-animation-default;
    -webkit-animation-duration: 3.0s;

    animation-name: flash-animation-default;
    animation-duration: 3.0s;
}

@-webkit-keyframes flash-animation-default {
    from { background: white; }
    from { background: #fdfd54; }
    to   { background: default; }
}

@keyframes flash-animation-default {
    from { background: white; }
    from { background: #fdfd54; }
    to   { background: default; }
}

/* generated by pygments */
.light .hll { background-color: #ffffcc }
.light .c { color: #408080; font-style: italic } /* Comment */
.light .err { border: 1px solid #FF0000 } /* Error */
.light .k { color: #008000; font-weight: bold } /* Keyword */
.light .o { color: #666666 } /* Operator */
.light .ch { color: #408080; font-style: italic } /* Comment.Hashbang */
.light .cm { color: #408080; font-style: italic } /* Comment.Multiline */
.light .cp { color: #BC7A00 } /* Comment.Preproc */
.light .cpf { color: #408080; font-style: italic } /* Comment.PreprocFile */
.light .c1 { color: #408080; font-style: italic } /* Comment.Single */
.light .cs { color: #408080; font-style: italic } /* Comment.Special */
.light .gd { color: #A00000 } /* Generic.Deleted */
.light .ge { font-style: italic } /* Generic.Emph */
.light .gr { color: #FF0000 } /* Generic.Error */
.light .gh { color: #000080; font-weight: bold } /* Generic.Heading */
.light .gi { color: #00A000 } /* Generic.Inserted */
.light .go { color: #888888 } /* Generic.Output */
.light .gp { color: #000080; font-weight: bold } /* Generic.Prompt */
.light .gs { font-weight: bold } /* Generic.Strong */
.light .gu { color: #800080; font-weight: bold } /* Generic.Subheading */
.light .gt { color: #0044DD } /* Generic.Traceback */
.light .kc { color: #008000; font-weight: bold } /* Keyword.Constant */
.light .kd { color: #008000; font-weight: bold } /* Keyword.Declaration */
.light .kn { color: #008000; font-weight: bold } /* Keyword.Namespace */
.light .kp { color: #008000 } /* Keyword.Pseudo */
.light .kr { color: #008000; font-weight: bold } /* Keyword.Reserved */
.light .kt { color: #B00040 } /* Keyword.Type */
.light .m { color: #666666 } /* Literal.Number */
.light .s { color: #BA2121 } /* Literal.String */
.light .na { color: #7D9029 } /* Name.Attribute */
.light .nb { color: #008000 } /* Name.Builtin */
.light .nc { color: #0000FF; font-weight: bold } /* Name.Class */
.light .no { color: #880000 } /* Name.Constant */
.light .nd { color: #AA22FF } /* Name.Decorator */
.light .ni { color: #999999; font-weight: bold } /* Name.Entity */
.light .ne { color: #D2413A; font-weight: bold } /* Name.Exception */
.light .nf { color: #0000FF } /* Name.Function */
.light .nl { color: #A0A000 } /* Name.Label */
.light .nn { color: #0000FF; font-weight: bold } /* Name.Namespace */
.light .nt { color: #008000; font-weight: bold } /* Name.Tag */
.light .nv { color: #19177C } /* Name.Variable */
.light .ow { color: #AA22FF; font-weight: bold } /* Operator.Word */
.light .w { color: #bbbbbb } /* Text.Whitespace */
.light .mb { color: #666666 } /* Literal.Number.Bin */
.light .mf { color: #666666 } /* Literal.Number.Float */
.light .mh { color: #666666 } /* Literal.Number.Hex */
.light .mi { color: #666666 } /* Literal.Number.Integer */
.light .mo { color: #666666 } /* Literal.Number.Oct */
.light .sa { color: #BA2121 } /* Literal.String.Affix */
.light .sb { color: #BA2121 } /* Literal.String.Backtick */
.light .sc { color: #BA2121 } /* Literal.String.Char */
.light .dl { color: #BA2121 } /* Literal.String.Delimiter */
.light .sd { color: #BA2121; font-style: italic } /* Literal.String.Doc */
.light .s2 { color: #BA2121 } /* Literal.String.Double */
.light .se { color: #BB6622; font-weight: bold } /* Literal.String.Escape */
.light .sh { color: #BA2121 } /* Literal.String.Heredoc */
.light .si { color: #BB6688; font-weight: bold } /* Literal.String.Interpol */
.light .sx { color: #008000 } /* Literal.String.Other */
.light .sr { color: #BB6688 } /* Literal.String.Regex */
.light .s1 { color: #BA2121 } /* Literal.String.Single */
.light .ss { color: #19177C } /* Literal.String.Symbol */
.light .bp { color: #008000 } /* Name.Builtin.Pseudo */
.light .fm { color: #0000FF } /* Name.Function.Magic */
.light .vc { color: #19177C } /* Name.Variable.Class */
.light .vg { color: #19177C } /* Name.Variable.Global */
.light .vi { color: #19177C } /* Name.Variable.Instance */
.light .vm { color: #19177C } /* Name.Variable.Magic */
.light .il { color: #666666 } /* Literal.Number.Integer.Long */
