.vim .hll { background-color: #222222 }
.vim .c { color: #000080 } /* Comment */
.vim .err { color: #cccccc; border: 1px solid #FF0000 } /* Error */
.vim .esc { color: #cccccc } /* Escape */
.vim .g { color: #cccccc } /* Generic */
.vim .k { color: #cdcd00 } /* Keyword */
.vim .l { color: #cccccc } /* Literal */
.vim .n { color: #cccccc } /* Name */
.vim .o { color: #3399cc } /* Operator */
.vim .x { color: #cccccc } /* Other */
.vim .p { color: #cccccc } /* Punctuation */
.vim .ch { color: #000080 } /* Comment.Hashbang */
.vim .cm { color: #000080 } /* Comment.Multiline */
.vim .cp { color: #000080 } /* Comment.Preproc */
.vim .cpf { color: #000080 } /* Comment.PreprocFile */
.vim .c1 { color: #000080 } /* Comment.Single */
.vim .cs { color: #cd0000; font-weight: bold } /* Comment.Special */
.vim .gd { color: #cd0000 } /* Generic.Deleted */
.vim .ge { color: #cccccc; font-style: italic } /* Generic.Emph */
.vim .gr { color: #FF0000 } /* Generic.Error */
.vim .gh { color: #000080; font-weight: bold } /* Generic.Heading */
.vim .gi { color: #00cd00 } /* Generic.Inserted */
.vim .go { color: #888888 } /* Generic.Output */
.vim .gp { color: #000080; font-weight: bold } /* Generic.Prompt */
.vim .gs { color: #cccccc; font-weight: bold } /* Generic.Strong */
.vim .gu { color: #800080; font-weight: bold } /* Generic.Subheading */
.vim .gt { color: #0044DD } /* Generic.Traceback */
.vim .kc { color: #cdcd00 } /* Keyword.Constant */
.vim .kd { color: #00cd00 } /* Keyword.Declaration */
.vim .kn { color: #cd00cd } /* Keyword.Namespace */
.vim .kp { color: #cdcd00 } /* Keyword.Pseudo */
.vim .kr { color: #cdcd00 } /* Keyword.Reserved */
.vim .kt { color: #00cd00 } /* Keyword.Type */
.vim .ld { color: #cccccc } /* Literal.Date */
.vim .m { color: #cd00cd } /* Literal.Number */
.vim .s { color: #cd0000 } /* Literal.String */
.vim .na { color: #cccccc } /* Name.Attribute */
.vim .nb { color: #cd00cd } /* Name.Builtin */
.vim .nc { color: #00cdcd } /* Name.Class */
.vim .no { color: #cccccc } /* Name.Constant */
.vim .nd { color: #cccccc } /* Name.Decorator */
.vim .ni { color: #cccccc } /* Name.Entity */
.vim .ne { color: #666699; font-weight: bold } /* Name.Exception */
.vim .nf { color: #cccccc } /* Name.Function */
.vim .nl { color: #cccccc } /* Name.Label */
.vim .nn { color: #cccccc } /* Name.Namespace */
.vim .nx { color: #cccccc } /* Name.Other */
.vim .py { color: #cccccc } /* Name.Property */
.vim .nt { color: #cccccc } /* Name.Tag */
.vim .nv { color: #00cdcd } /* Name.Variable */
.vim .ow { color: #cdcd00 } /* Operator.Word */
.vim .w { color: #cccccc } /* Text.Whitespace */
.vim .mb { color: #cd00cd } /* Literal.Number.Bin */
.vim .mf { color: #cd00cd } /* Literal.Number.Float */
.vim .mh { color: #cd00cd } /* Literal.Number.Hex */
.vim .mi { color: #cd00cd } /* Literal.Number.Integer */
.vim .mo { color: #cd00cd } /* Literal.Number.Oct */
.vim .sa { color: #cd0000 } /* Literal.String.Affix */
.vim .sb { color: #cd0000 } /* Literal.String.Backtick */
.vim .sc { color: #cd0000 } /* Literal.String.Char */
.vim .dl { color: #cd0000 } /* Literal.String.Delimiter */
.vim .sd { color: #cd0000 } /* Literal.String.Doc */
.vim .s2 { color: #cd0000 } /* Literal.String.Double */
.vim .se { color: #cd0000 } /* Literal.String.Escape */
.vim .sh { color: #cd0000 } /* Literal.String.Heredoc */
.vim .si { color: #cd0000 } /* Literal.String.Interpol */
.vim .sx { color: #cd0000 } /* Literal.String.Other */
.vim .sr { color: #cd0000 } /* Literal.String.Regex */
.vim .s1 { color: #cd0000 } /* Literal.String.Single */
.vim .ss { color: #cd0000 } /* Literal.String.Symbol */
.vim .bp { color: #cd00cd } /* Name.Builtin.Pseudo */
.vim .fm { color: #cccccc } /* Name.Function.Magic */
.vim .vc { color: #00cdcd } /* Name.Variable.Class */
.vim .vg { color: #00cdcd } /* Name.Variable.Global */
.vim .vi { color: #00cdcd } /* Name.Variable.Instance */
.vim .vm { color: #00cdcd } /* Name.Variable.Magic */
.vim .il { color: #cd00cd } /* Literal.Number.Integer.Long */
